@@ -3,8 +3,8 @@ package Cobol::Compiler::COBOLMasterSymbolTable;
 sub new {
 	my ($class) = @_;
 
-	my $self = { IDENTIFICATION => undef, 
-			DATAID => undef, 
+	my $self = { IDENTIFICATION => undef,
+			PROGRAM-ID => undef,
 			MAINPROCEDURE => undef, };
 
 	$class = ref($class) || $class;
